@@ -1,10 +1,10 @@
 """Example testing uncertainty with libsbml packages."""
-import os
 import tempfile
 from pathlib import Path
 
 import libsbml
 
+from sbmlutils import RESOURCES_DIR
 from sbmlutils.log import get_logger
 
 
@@ -13,9 +13,8 @@ logger = get_logger(__name__)
 
 def add_uncertainty_example(tmp: bool = False) -> None:
     """Add uncertainty to a model."""
-    output_dir = str(Path(__file__).parent)
     doc: libsbml.SBMLDocument = libsbml.readSBMLFromFile(
-        os.path.join(output_dir, "e_coli_core.xml")
+        str(RESOURCES_DIR / "distrib" / "e_coli_core.xml")
     )
 
     # activate distrib
@@ -29,9 +28,7 @@ def add_uncertainty_example(tmp: bool = False) -> None:
 
     # write gene expression data
     gp = model_fbc.getGeneProduct(0)
-    print(gp)
     gp_distrib: libsbml.DistribSBasePlugin = gp.getPlugin("distrib")
-    print(gp_distrib)
 
     if gp_distrib:
         uncertainty: libsbml.Uncertainty = gp_distrib.createUncertainty()
@@ -48,7 +45,7 @@ def add_uncertainty_example(tmp: bool = False) -> None:
             libsbml.writeSBMLToFile(doc, f_sbml.name)
     else:
         libsbml.writeSBMLToFile(
-            doc, os.path.join(output_dir, "e_coli_core_expression.xml")
+            doc, str(RESOURCES_DIR / "distrib" / "e_coli_core_expression.xml")
         )
 
 
