@@ -1,8 +1,8 @@
 """Example model with meta-data annotations."""
-from sbmlutils import EXAMPLES_DIR
 from sbmlutils.examples import templates
 from sbmlutils.factory import *
 from sbmlutils.metadata import *
+from sbmlutils.resources import EXAMPLES_DIR
 
 
 class U(Units):
