@@ -1,7 +1,7 @@
 """AssignmentRule and InitialAssignment example."""
-from sbmlutils import EXAMPLES_DIR
 from sbmlutils.examples import templates
 from sbmlutils.factory import *
+from sbmlutils.resources import EXAMPLES_DIR
 
 
 class U(Units):
