@@ -1,13 +1,14 @@
 """DallMan model factory."""
 from pathlib import Path
 
-from sbmlutils.creator import create_model
+from sbmlutils.examples.dallaman.model import dallaman_model
+from sbmlutils.factory import create_model
 
 
 def create(tmp: bool = False) -> None:
     """Create model."""
     create_model(
-        modules=["sbmlutils.examples.dallaman.model"],
+        models=dallaman_model,
         output_dir=Path(__file__).parent / "results",
         tmp=tmp,
         units_consistency=False,
