@@ -5,11 +5,11 @@ from pathlib import Path
 
 import libsbml
 
-from sbmlutils import EXAMPLES_DIR
 from sbmlutils.comp import flatten_sbml
 from sbmlutils.examples import templates
 from sbmlutils.factory import *
 from sbmlutils.metadata import *
+from sbmlutils.resources import EXAMPLES_DIR
 
 
 class U(Units):
