@@ -1,15 +1,19 @@
-"""Example creating minimal model.
+"""Example creating linear chain.
 
-This demonstrates just the very core SBML functionality.
+This demonstrates core SBML functionality in combination with using patterns.
+`sbmlutils` allows to generate patterns of objects by combining loops in combination
+with string patterns. In this example we create a kinetic model of a linear chain.
 """
 from pathlib import Path
 from typing import List
 
-from sbmlutils import EXAMPLES_DIR
+import libsbml
+
 from sbmlutils.cytoscape import visualize_sbml
 from sbmlutils.examples import templates
 from sbmlutils.factory import *
 from sbmlutils.metadata import *
+from sbmlutils.resources import EXAMPLES_DIR
 
 
 n_chain = 20
