@@ -1,10 +1,10 @@
 """Create reaction example."""
 import numpy as np
 
-from sbmlutils import EXAMPLES_DIR
 from sbmlutils.examples import templates
 from sbmlutils.factory import *
 from sbmlutils.metadata import *
+from sbmlutils.resources import EXAMPLES_DIR
 
 
 _m = Model(
