@@ -1068,9 +1068,15 @@ class SBMLDocumentInfo:
             else:
                 d["trigger"] = None
 
-            d["priority"] = (
-                astnode_to_latex(event.getPriority()) if event.isSetPriority() else None
+            priority: libsbml.Priority = (
+                event.getPriority() if event.isSetPriority() else None
             )
+            if priority:
+                d["priority"] = (
+                    astnode_to_latex(priority.getMath())
+                    if priority.isSetMath()
+                    else None
+                )
             delay: libsbml.Delay = event.getDelay() if event.isSetDelay() else None
             if delay:
                 d["delay"] = (
@@ -1240,12 +1246,12 @@ class SBMLDocumentInfo:
 if __name__ == "__main__":
     from pathlib import Path
 
-    output_dir = Path(__file__).parent / "test"
+    output_dir = Path(__file__).parent / "tests"
     if not output_dir.exists():
         output_dir.mkdir(parents=True, exist_ok=True)
 
     print("-" * 80)
-    from sbmlutils.test import GLUCOSE_SBML
+    from sbmlutils.resources import GLUCOSE_SBML
 
     for source in [
         # COMP_ICG_BODY,
@@ -1256,6 +1262,7 @@ if __name__ == "__main__":
         # FBC_ECOLI_CORE_SBML,
         # DISTRIB_DISTRIBUTIONS_SBML,
         # DISTRIB_UNCERTAINTIES_SBML,
+        # output_dir / "icg_body_flat_v2.xml",
         GLUCOSE_SBML
         # REPRESSILATOR_SBML,
     ]:
@@ -1265,19 +1272,5 @@ if __name__ == "__main__":
         print(json_str)
         print("-" * 80)
 
-    with open(output_dir / "test.json", "w") as fout:
+    with open(output_dir / "tests.json", "w") as fout:
         fout.write(json_str)
-
-    doc = libsbml.SBMLDocument()
-    model: libsbml.Model = doc.createModel()
-    udef = model.getUnitDefinition("dimensionless")
-    print("udef", udef)
-
-    print(libsbml.UnitKind_toString(libsbml.UNIT_KIND_DIMENSIONLESS))
-    udef = model.getUnitDefinition("metre")
-    print("udef", udef)
-
-    print(libsbml.UnitKind_forName("dimensionless"))
-    print(libsbml.UnitKind_forName("abc"))
-    print(libsbml.UnitKind_toString(libsbml.UNIT_KIND_INVALID))
-    print(libsbml.UnitKind_toString(36))
